
# sme

[![pypi releases](https://img.shields.io/pypi/v/sme.svg)](https://pypi.org/project/sme)
[![open in colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/spatial-model-editor/spatial-model-editor/blob/main/docs/sme/notebooks/getting_started.ipynb)
[![python versions](https://img.shields.io/pypi/pyversions/sme)](https://pypi.org/project/sme)

sme is the Python interface to [Spatial Model Editor](https://spatial-model-editor.github.io).

It can be used to modify parameters in a model and to simulate a model.
See the [documentation](https://spatial-model-editor.readthedocs.io/en/stable/sme/sme.html) for more information.

It can be installed from [PyPI](https://pypi.org/project/sme/) using pip:

```
pip install sme
```

You can also [try it out][1] online without installing anything using Google Colab
(click on `Runtime -> Run all` or press `Ctrl+F9` to get started)

[1]: https://colab.research.google.com/github/spatial-model-editor/spatial-model-editor/blob/main/docs/sme/notebooks/getting_started.ipynb

For additional functionality such as plotting and parameter fitting, see [sme-contrib](https://sme-contrib.readthedocs.io/)
